=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2006-03-08 08:07:38 +0000
+++ bzrlib/branch.py	2006-03-08 09:30:27 +0000
@@ -51,6 +51,7 @@
 import bzrlib.inventory as inventory
 from bzrlib.inventory import Inventory
 from bzrlib.lockable_files import LockableFiles, TransportLock
+from bzrlib.lockdir import LockDir
 from bzrlib.osutils import (isdir, quotefn,
                             rename, splitpath, sha_file,
                             file_kind, abspath, normpath, pathjoin,
@@ -658,8 +659,11 @@
     This format has:
      - a revision-history file.
      - a format string
-     - a lock file.
+     - a lock dir guarding the branch itself
+     - all of this stored in a branch/ subdirectory
      - works with shared repositories.
+
+    This format is new in bzr 0.8.
     """
 
     def get_format_string(self):
@@ -668,13 +672,12 @@
         
     def initialize(self, a_bzrdir):
         """Create a branch of this format in a_bzrdir."""
-        mutter('creating branch in %s', a_bzrdir.transport.base)
+        mutter('creating branch %r in %s', self, a_bzrdir.transport.base)
         branch_transport = a_bzrdir.get_branch_transport(self)
-
         utf8_files = [('revision-history', ''),
                       ('branch-name', ''),
                       ]
-        control_files = LockableFiles(branch_transport, 'lock', TransportLock)
+        control_files = LockableFiles(branch_transport, 'lock', LockDir)
         control_files.create_lock()
         control_files.lock_write()
         control_files.put_utf8('format', self.get_format_string())
@@ -699,7 +702,7 @@
             format = BranchFormat.find_format(a_bzrdir)
             assert format.__class__ == self.__class__
         transport = a_bzrdir.get_branch_transport(None)
-        control_files = LockableFiles(transport, 'lock', TransportLock)
+        control_files = LockableFiles(transport, 'lock', LockDir)
         return BzrBranch5(_format=self,
                           _control_files=control_files,
                           a_bzrdir=a_bzrdir,

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2006-03-08 07:55:41 +0000
+++ bzrlib/bzrdir.py	2006-03-08 09:30:27 +0000
@@ -151,8 +151,8 @@
             except errors.FileExists:
                 pass
 
-    @staticmethod
-    def create(base):
+    @classmethod
+    def create(cls, base):
         """Create a new BzrDir at the url 'base'.
         
         This will call the current default formats initialize with base
@@ -161,6 +161,9 @@
         If you need a specific format, consider creating an instance
         of that and calling initialize().
         """
+        if cls is not BzrDir:
+            raise AssertionError("BzrDir.create always creates the default format, "
+                    "not one of %r" % cls)
         segments = base.split('/')
         if segments and segments[-1] not in ('', '.'):
             parent = '/'.join(segments[:-1])

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2006-02-13 21:52:05 +0000
+++ bzrlib/tests/test_branch.py	2006-03-08 09:30:27 +0000
@@ -1,15 +1,15 @@
-# (C) 2005 Canonical Ltd
-
+# Copyright (C) 2005, 2006 Canonical Ltd
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -25,7 +25,11 @@
 from StringIO import StringIO
 
 import bzrlib.branch
+from bzrlib.branch import (BzrBranch5, 
+                           BzrBranchFormat5)
 import bzrlib.bzrdir as bzrdir
+from bzrlib.bzrdir import (BzrDirMetaFormat1, BzrDirMeta1, 
+                           BzrDir, BzrDirFormat)
 from bzrlib.errors import (NotBranchError,
                            UnknownFormatError,
                            UnsupportedFormatError,
@@ -44,7 +48,7 @@
         try:
             # the default branch format is used by the meta dir format
             # which is not the default bzrdir format at this point
-            dir = bzrdir.BzrDirMetaFormat1().initialize('memory:/')
+            dir = BzrDirMetaFormat1().initialize('memory:/')
             result = dir.create_branch()
             self.assertEqual(result, 'A branch')
         finally:
@@ -52,6 +56,26 @@
         self.assertEqual(old_format, bzrlib.branch.BranchFormat.get_default_format())
 
 
+class TestBranchFormat5(TestCaseWithTransport):
+    """Tests specific to branch format 5"""
+
+    def test_branch_format_5_uses_lockdir(self):
+        # XXX: There's really got to be a better way than setting the default
+        # format!  All I want is to create a bzrdir of a specified format.
+        url = self.get_url()
+        old_format = bzrdir.BzrDirFormat.get_default_format()
+        BzrDirFormat.set_default_format(bzrdir.BzrDirMetaFormat1())
+        try:
+            branch = BzrDir.create_branch_and_repo(url)
+            self.log("branch instance is %r" % branch)
+            self.assert_(isinstance(branch, BzrBranch5))
+            self.assertIsDirectory('.', self.get_transport())
+            self.assertIsDirectory('.bzr/branch', self.get_transport())
+            self.assertIsDirectory('.bzr/branch/lock', self.get_transport())
+        finally:
+            bzrdir.BzrDirFormat.set_default_format(old_format)
+
+
 class SampleBranchFormat(bzrlib.branch.BranchFormat):
     """A sample format
 

